import { ComputedRef, Ref, ShallowRef } from 'vue';
import { default as BaseObject, ObjectEvent } from 'ol/Object';
import { default as BaseEvent } from 'ol/events/Event';
import { default as RenderEvent } from 'ol/render/Event';
import { TileSourceEvent } from 'ol/source/Tile';
import { ImageSourceEvent } from 'ol/source/Image';
import { VectorSourceEvent } from 'ol/source/Vector';

export declare const COMMON_EVENTS: string[];
export interface CommonEvents {
    (e: "change", event: BaseEvent): void;
    (e: "error", event: BaseEvent): void;
    (e: "propertychange", event: ObjectEvent): void;
}
export declare const LAYER_EVENTS: string[];
export interface LayerChangeEvents {
    (e: "change:extent", event: ObjectEvent): void;
    (e: "change:maxResolution", event: ObjectEvent): void;
    (e: "change:maxZoom", event: ObjectEvent): void;
    (e: "change:minResolution", event: ObjectEvent): void;
    (e: "change:minZoom", event: ObjectEvent): void;
    (e: "change:opacity", event: ObjectEvent): void;
    (e: "change:source", event: ObjectEvent): void;
    (e: "change:visible", event: ObjectEvent): void;
    (e: "change:zIndex", event: ObjectEvent): void;
}
export interface LayerRenderEvents {
    (e: "postrender", event: RenderEvent): void;
    (e: "prerender", event: RenderEvent): void;
}
export interface LayerEvents extends CommonEvents, LayerChangeEvents, LayerRenderEvents {
    (e: "sourceready", event: BaseEvent): void;
}
export declare const TILE_SOURCE_EVENTS: string[];
export interface TileSourceEvents extends CommonEvents {
    (e: "tileloadend", event: TileSourceEvent): void;
    (e: "tileloaderror", event: TileSourceEvent): void;
    (e: "tileloadstart", event: TileSourceEvent): void;
}
export declare const IMAGE_SOURCE_EVENTS: string[];
export interface ImageSourceEvents extends CommonEvents {
    (e: "imageloadend", event: ImageSourceEvent): void;
    (e: "imageloaderror", event: ImageSourceEvent): void;
    (e: "imageloadstart", event: ImageSourceEvent): void;
}
export declare const VECTOR_SOURCE_EVENTS: string[];
export interface VectorSourceEvents extends CommonEvents {
    (e: "addfeature", event: VectorSourceEvent): void;
    (e: "changefeature", event: VectorSourceEvent): void;
    (e: "clear", event: VectorSourceEvent): void;
    (e: "featuresloadend", event: VectorSourceEvent): void;
    (e: "featuresloaderror", event: VectorSourceEvent): void;
    (e: "featuresloadstart", event: VectorSourceEvent): void;
    (e: "removefeature", event: VectorSourceEvent): void;
}
export declare function useOpenLayersEvents(feature: BaseObject | Ref<BaseObject> | ShallowRef<BaseObject> | ComputedRef<BaseObject>, eventNames: string[]): {
    updateOpenLayersEventHandlers: () => void;
};
